@@ -2,6 +2,8 @@
 #include <string>
 #include <cstdlib>
 
+#include <csignal>
+
 #include <ting/Socket.hpp>
 #include <ting/Timer.hpp>
 
@@ -11,6 +13,14 @@
 using namespace ting;
 
 
+Therver* therverPtr = 0;
+
+static void ExitSignalHandler(int sigNum){
+	//TODO: this may block, need to investigate other approach of catching signals
+	//in separate thread.
+	ASS(therverPtr)->PushQuitMessage();
+}
+
 
 int main(int argc, char *argv[]) throw(){
 	try{
@@ -40,7 +50,23 @@ int main(int argc, char *argv[]) throw(){
         
         {
             Therver s(port, dataDir);
+
+			therverPtr = &s;
+
+			//set signal handler
+			struct sigaction sa;
+			sa.sa_handler = &ExitSignalHandler;
+			sa.sa_flags = 0;
+			sigemptyset(&sa.sa_mask);//init sa_mask to empty set (no signals)
+			ASSERT_EXEC(sigaction(SIGINT, &sa, 0) == 0)
+			
             s.MainLoop();
+
+			//clear signal handler
+			sa.sa_handler = SIG_DFL;
+			ASSERT_EXEC(sigaction(SIGINT, &sa, 0) == 0)
+
+			therverPtr = 0;
         }
         
     }//~try
@@ -56,6 +82,6 @@ int main(int argc, char *argv[]) throw(){
     catch(...){
         LOG(<<"[!!] Unknown exception caught!"<<"\n\t!!!Global exception!!! Exiting."<<std::endl)
     }
-    LOG(<<"Bye!"<<std::endl)
+    TRACE(<<"Bye!"<<std::endl)
     return 0; //exit
 };
