@@ -56,6 +56,9 @@ MainWindow::MainWindow() :
 {
 	this->set_default_size(800, 480);
 
+	this->signal_key_press_event().connect_notify(
+			sigc::mem_fun(*this, &MainWindow::OnKeyPress_Notify)
+		);
 	this->signal_key_press_event().connect(
 			sigc::mem_fun(*this, &MainWindow::OnKeyPress)
 		);
@@ -132,16 +135,22 @@ struct MenuPlacer{
 
 
 
+void MainWindow::ToggleFullscreen(){
+	if(this->isFullscreen)
+		this->unfullscreen();
+	else
+		this->fullscreen();
+	this->isFullscreen = !this->isFullscreen;
+}
+
+
+
 bool MainWindow::OnKeyPress(GdkEventKey* event){
 	TRACE(<<"OnKeyPress(): keyval = " << event->keyval << std::endl)
 	switch(event->keyval){
 		case GDK_F6:
 //			TRACE(<<"OnKeyPress(): f6 pressed" << std::endl)
-			if(this->isFullscreen)
-				this->unfullscreen();
-			else
-				this->fullscreen();
-			this->isFullscreen = !this->isFullscreen;
+			this->ToggleFullscreen();
 			break;
 
 		case GDK_F4:
@@ -164,3 +173,15 @@ bool MainWindow::OnKeyPress(GdkEventKey* event){
 }
 
 
+void MainWindow::OnKeyPress_Notify(GdkEventKey* event){
+	TRACE(<<"OnKeyPress_Notify(): keyval = " << event->keyval << std::endl)
+	switch(event->keyval){
+		case GDK_space:
+			this->ToggleFullscreen();
+			break;
+		default:
+			break;
+	}
+}
+
+
