@@ -125,11 +125,14 @@ public:
 	}
 
 	bool OnKeyPress(GdkEventKey* event);
-//	void OnKeyPress_Notify(GdkEventKey* event);
+	void OnKeyPress_Notify(GdkEventKey* event);
 
 	void ShowAboutDialog();
 
 	void Exit();
+
+private:
+	void ToggleFullscreen();
 };
 
 
